@@ -29,10 +29,11 @@ class PluginBase:
     # TODO: Add class generic identifier
     class_signature = "PluginBase"
 
-    def __init__(self):
+    def __init__(self, ignore_info=False):
         # Must be unique. Check that there is not
         # an existant plugin with the same id.
         # TODO: Make script that list current ids.
+        self.ignore_info = ignore_info
         self.id = None
         self.auto_load = True
         self._rid = id(self)
@@ -138,26 +139,32 @@ class PluginBase:
         return obj_uuid
 
     def save_service_vuln_cache(self, host_id, service_id, vuln):
-        cache_id = self.get_service_vuln_cache_id(host_id, service_id, vuln)
-        if cache_id not in self._vulns_cache:
-            obj_uuid = self.save_cache(vuln)
-            service = self.get_from_cache(service_id)
-            service["vulnerabilities"].append(vuln)
-            self._vulns_cache[cache_id] = obj_uuid
+        if self.ignore_info and vuln['severity'] == 'info':
+            return None
         else:
-            obj_uuid = self._vulns_cache[cache_id]
-        return obj_uuid
+            cache_id = self.get_service_vuln_cache_id(host_id, service_id, vuln)
+            if cache_id not in self._vulns_cache:
+                obj_uuid = self.save_cache(vuln)
+                service = self.get_from_cache(service_id)
+                service["vulnerabilities"].append(vuln)
+                self._vulns_cache[cache_id] = obj_uuid
+            else:
+                obj_uuid = self._vulns_cache[cache_id]
+            return obj_uuid
 
     def save_host_vuln_cache(self, host_id, vuln):
-        cache_id = self.get_host_vuln_cache_id(host_id, vuln)
-        if cache_id not in self._vulns_cache:
-            obj_uuid = self.save_cache(vuln)
-            host = self.get_from_cache(host_id)
-            host["vulnerabilities"].append(vuln)
-            self._vulns_cache[cache_id] = obj_uuid
+        if self.ignore_info and vuln['severity'] == 'info':
+            return None
         else:
-            obj_uuid = self._vulns_cache[cache_id]
-        return obj_uuid
+            cache_id = self.get_host_vuln_cache_id(host_id, vuln)
+            if cache_id not in self._vulns_cache:
+                obj_uuid = self.save_cache(vuln)
+                host = self.get_from_cache(host_id)
+                host["vulnerabilities"].append(vuln)
+                self._vulns_cache[cache_id] = obj_uuid
+            else:
+                obj_uuid = self._vulns_cache[cache_id]
+            return obj_uuid
 
     @staticmethod
     def _get_dict_hash(d, keys):
@@ -296,7 +303,7 @@ class PluginBase:
 
     def processReport(self, filepath, user="faraday"):
         if os.path.isfile(filepath):
-            self.vulns_data["command"]["params"] = filepath
+            self.vulns_data["command"]["params"] = filepath if not self.ignore_info else f"{filepath} (Info ignored)"
             self.vulns_data["command"]["user"] = user
             self.vulns_data["command"]["import_source"] = "report"
             self._parse_filename(filepath)
@@ -376,7 +383,8 @@ class PluginBase:
             tags = [tags]
         vulnerability = {"name": name, "desc": desc, "severity": self.normalize_severity(severity), "refs": ref,
                          "external_id": external_id, "type": "Vulnerability", "resolution": resolution, "data": data,
-                         "custom_fields": custom_fields, "status": status, "impact": impact, "policyviolations": policyviolations,
+                         "custom_fields": custom_fields, "status": status, "impact": impact,
+                         "policyviolations": policyviolations,
                          "confirmed": confirmed, "easeofresolution": easeofresolution, "tags": tags
                          }
         if run_date:
@@ -545,8 +553,8 @@ class PluginCustomOutput(PluginBase):
 
 
 class PluginByExtension(PluginBase):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.extension = []
 
     def report_belongs_to(self, extension="", **kwargs):
@@ -561,8 +569,8 @@ class PluginByExtension(PluginBase):
 
 class PluginXMLFormat(PluginByExtension):
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.identifier_tag = []
         self.extension = ".xml"
         self.open_options = {"mode": "rb"}
@@ -580,8 +588,8 @@ class PluginXMLFormat(PluginByExtension):
 
 class PluginJsonFormat(PluginByExtension):
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.json_keys = set()
         self.extension = ".json"
 
@@ -597,8 +605,8 @@ class PluginJsonFormat(PluginByExtension):
 
 class PluginMultiLineJsonFormat(PluginByExtension):
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.json_keys = set()
         self.extension = ".json"
 
@@ -622,8 +630,8 @@ class PluginMultiLineJsonFormat(PluginByExtension):
 
 class PluginCSVFormat(PluginByExtension):
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.extension = ".csv"
         self.csv_headers = set()
 
@@ -642,8 +650,8 @@ class PluginCSVFormat(PluginByExtension):
 
 class PluginZipFormat(PluginByExtension):
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, ignore_info=False):
+        super().__init__(ignore_info)
         self.extension = ".zip"
         self.files_list = set()
 
