@@ -23,8 +23,8 @@ class BeefPlugin(PluginBase):
     Example plugin to parse beef output.
     """
 
-    def __init__(self):
-        super().__init__()
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.id = "Beef"
         self.name = "BeEF Online Service Plugin"
         self.plugin_version = "0.0.1"
@@ -40,7 +40,7 @@ class BeefPlugin(PluginBase):
             "Authkey", str, "c818c7798ae1da38b45a6406c8dd0d6d4d007098")
         self.addSetting("Enable", str, "0")
 
-    def parseOutputString(self, output, debug=False):
+    def parseOutputString(self, output):
         """
         This method will discard the output the shell sends, it will read it from
         the xml where it expects it to be present.
@@ -99,6 +99,6 @@ class BeefPlugin(PluginBase):
         pass
 
 
-def createPlugin():
-    return BeefPlugin()
+def createPlugin(ignore_info=False):
+    return BeefPlugin(ignore_info=ignore_info)
 
