@@ -79,8 +79,9 @@ class Querys():
 
 
 class CheckmarxPlugin(PluginXMLFormat):
-    def __init__(self):
-        super().__init__()
+
+    def __init__(self, *arg, **kwargs):
+        super().__init__(*arg, **kwargs)
         self.identifier_tag = ["CxXMLResults"]
         self.id = 'Checkmarx'
         self.name = 'Checkmarx XML Output Plugin'
@@ -137,6 +138,6 @@ class CheckmarxPlugin(PluginXMLFormat):
                                               resolution=data, ref=refs)
 
 
-def createPlugin():
-    return CheckmarxPlugin()
+def createPlugin(ignore_info=False):
+    return CheckmarxPlugin(ignore_info=ignore_info)
 
